@@ -1,15 +1,4 @@
-"""
-PDF Specification Archive
-https://pdfa.org/resource/pdf-specification-archive/
-
-Portable Document Format Reference Manual, 1993. ISBN 0-201-62628-4
-https://opensource.adobe.com/dc-acrobat-sdk-docs/pdfstandards/pdfreference1.0.pdf
-
-ISO 32000-1:2008 (PDF 1.7)
-https://opensource.adobe.com/dc-acrobat-sdk-docs/pdfstandards/PDF32000_2008.pdf
-
-ISO 32000-2:2020 (PDF 2.0)
-"""
+"""Various constants, enums, and flags to aid readability."""
 
 from enum import Enum, IntFlag, auto, unique
 from typing import Dict, Tuple
@@ -31,12 +20,12 @@ class Core:
 
 
 class TrailerKeys:
-    ROOT = "/Root"
-    ENCRYPT = "/Encrypt"
-    ID = "/ID"
-    INFO = "/Info"
     SIZE = "/Size"
     PREV = "/Prev"
+    ROOT = "/Root"
+    ENCRYPT = "/Encrypt"
+    INFO = "/Info"
+    ID = "/ID"
 
 
 class CatalogAttributes:
@@ -53,7 +42,7 @@ class EncryptionDictAttributes:
     """
 
     R = "/R"  # number, required; revision of the standard security handler
-    O = "/O"  # 32-byte string, required  # noqa
+    O = "/O"  # 32-byte string, required  # noqa: E741
     U = "/U"  # 32-byte string, required
     P = "/P"  # integer flag, required; permitted operations
     ENCRYPT_METADATA = "/EncryptMetadata"  # boolean flag, optional
@@ -143,8 +132,6 @@ class UserAccessPermissions(IntFlag):
 class Resources:
     """
     Table 3.30 Entries in a resource dictionary.
-    Used to be Ressources (a misspelling).
-
     Table 34 in the 2.0 reference.
     """
 
@@ -172,7 +159,6 @@ class PagesAttributes:
     TYPE = "/Type"  # name, required; must be /Pages
     PARENT = "/Parent"  # dictionary, required; indirect reference to pages object
     KIDS = "/Kids"  # array, required; List of indirect references
-
     COUNT = "/Count"
     # integer, required; the number of leaf nodes (page objects)
     # that are descendants of this node within the page tree
@@ -223,14 +209,14 @@ class FileSpecificationDictionaryEntries:
 
     Type = "/Type"
     FS = "/FS"  # The name of the file system to be used to interpret this file specification
-    F = "/F"  # A file specification string of the form described in Section 3.10.1
-    UF = "/UF"  # A unicode string of the file as described in Section 3.10.1
+    F = "/F"  # A file specification string of the form described in §3.10.1
+    UF = "/UF"  # A Unicode string of the file as described in §3.10.1
     DOS = "/DOS"
     Mac = "/Mac"
     Unix = "/Unix"
     ID = "/ID"
     V = "/V"
-    EF = "/EF"  # dictionary, containing a subset of the keys F , UF , DOS , Mac , and Unix
+    EF = "/EF"  # dictionary, containing a subset of the keys F, UF, DOS, Mac, and Unix
     RF = "/RF"  # dictionary, containing arrays of /EmbeddedFile
     DESC = "/Desc"  # description of the file
     Cl = "/Cl"
@@ -254,7 +240,7 @@ class FilterTypes(StrEnum):
     ASCII_HEX_DECODE = "/ASCIIHexDecode"  # abbreviation: AHx
     ASCII_85_DECODE = "/ASCII85Decode"  # abbreviation: A85
     LZW_DECODE = "/LZWDecode"  # abbreviation: LZW
-    FLATE_DECODE = "/FlateDecode"  # abbreviation: Fl, PDF 1.2
+    FLATE_DECODE = "/FlateDecode"  # abbreviation: Fl
     RUN_LENGTH_DECODE = "/RunLengthDecode"  # abbreviation: RL
     CCITT_FAX_DECODE = "/CCITTFaxDecode"  # abbreviation: CCF
     DCT_DECODE = "/DCTDecode"  # abbreviation: DCT
@@ -267,7 +253,7 @@ class FilterTypeAbbreviations:
     AHx = "/AHx"
     A85 = "/A85"
     LZW = "/LZW"
-    FL = "/Fl"  # FlateDecode
+    FL = "/Fl"
     RL = "/RL"
     CCF = "/CCF"
     DCT = "/DCT"
@@ -338,19 +324,20 @@ class TypArguments:
 class TypFitArguments:
     """Table 8.2 of the PDF 1.7 reference."""
 
-    FIT = "/Fit"
-    FIT_V = "/FitV"
-    FIT_BV = "/FitBV"
-    FIT_B = "/FitB"
-    FIT_H = "/FitH"
-    FIT_BH = "/FitBH"
-    FIT_R = "/FitR"
     XYZ = "/XYZ"
+    FIT = "/Fit"
+    FIT_H = "/FitH"
+    FIT_V = "/FitV"
+    FIT_R = "/FitR"
+    FIT_B = "/FitB"
+    FIT_BH = "/FitBH"
+    FIT_BV = "/FitBV"
 
 
 class GoToActionArguments:
     S = "/S"  # name, required: type of action
-    D = "/D"  # name / byte string /array, required: Destination to jump to
+    D = "/D"  # name, byte string, or array, required: destination to jump to
+    SD = "/SD"  # array, optional: structure destination to jump to
 
 
 class AnnotationDictionaryAttributes:
@@ -402,16 +389,16 @@ class FieldDictionaryAttributes:
     V = "/V"  # text string or array, optional
     DV = "/DV"  # text string, optional
     AA = "/AA"  # dictionary, optional
-    Opt = "/Opt"
+    Opt = "/Opt"  # array, optional
 
     class FfBits(IntFlag):
         """
         Ease building /Ff flags
         Some entries may be specific to:
 
-        * Text(Tx) (Table 8.75 PDF 1.7 reference)
-        * Buttons(Btn) (Table 8.77 PDF 1.7 reference)
-        * List(Ch) (Table 8.79 PDF 1.7 reference)
+        * Text (Tx) (Table 8.75 PDF 1.7 reference)
+        * Buttons (Btn) (Table 8.77 PDF 1.7 reference)
+        * Choice (Ch) (Table 8.79 PDF 1.7 reference)
         """
 
         ReadOnly = 1 << 0
@@ -474,6 +461,7 @@ class FieldDictionaryAttributes:
 
         Returns:
             A tuple containing all the attribute constants.
+
         """
         return (
             cls.TM,
@@ -501,6 +489,7 @@ class FieldDictionaryAttributes:
 
         Returns:
             A dictionary containing attribute keys and their names.
+
         """
         return {
             cls.FT: "Field Type",
@@ -531,6 +520,7 @@ class CheckboxRadioButtonAttributes:
 
         Returns:
             A tuple containing all the attribute constants.
+
         """
         return (cls.Opt,)
 
@@ -547,6 +537,7 @@ class CheckboxRadioButtonAttributes:
 
         Returns:
             A dictionary containing attribute keys and their names.
+
         """
         return {
             cls.Opt: "Options",
@@ -704,12 +695,13 @@ PDF_KEYS = (
     DocumentInformationAttributes,
     EncryptionDictAttributes,
     FieldDictionaryAttributes,
+    FileSpecificationDictionaryEntries,
     FilterTypeAbbreviations,
     FilterTypes,
     GoToActionArguments,
     GraphicsStateParameters,
     ImageAttributes,
-    FileSpecificationDictionaryEntries,
+    InteractiveFormDictEntries,
     LzwFilterParameters,
     PageAttributes,
     PageLayouts,
